from setuptools import setup

setup(
    name='coolgpus',
    version='0.15',
    description='GPU fan control for (partially?) headless Linux',
    url='https://github.com/andyljones/coolgpus',
    author='Andy L Jones',
    email='andyjones.ed@gmail.com',
    license='MIT',
    scripts=['coolgpus']
    )
